# lh-tool Package

This is a tool package. 

# Tools

* image2video
* video2image
* image2image
* image2gif
* image2pdf
* pdf2image
* play_images
* startup
* excel2latex
* excel2markdown

# Install

* Installing from source
```shell
git clone https://github.com/lh9171338/lh-tool.git

cd lh-tool

py -m build

pip install dist/lh_tool-1.0.0-py3-none-any.whl
```

* Install from the Python Package Index (PyPI)
```shell
pip install lh_tool
```